import "../fixtures";
import Video from "model/video";
import Photo from "model/photo";
import File from "model/file";

let chai = require("chai/chai");
let assert = chai.assert;

describe("model/video", () => {
  it("should get video defaults", () => {
    const values = {
      UID: "",
      PhotoUID: "",
      Hash: "",
      PosterHash: "",
      Title: "",
      Description: "",
      TakenAt: "",
      Favorite: false,
      Playable: false,
      HDR: false,
      Mime: "",
      Type: "",
      Codec: "",
      Width: 640,
      Height: 480,
      Duration: 0,
      FPS: 0,
      Frames: 0,
      Projection: "",
      ColorProfile: "",
      Error: "",
    };

    const video = new Video(values);
    const result = video.getDefaults();
    assert.deepEqual(values, result);
  });

  it("should get uid", () => {
    const values = {
      UID: "frw5e3e256rk0hr7",
      PhotoUID: "prqjmzr1jlmr4mpb",
    };
    const video = new Video(values);
    assert.equal(video.getId(), "frw5e3e256rk0hr7");
  });

  it("should return hasId", () => {
    const values = {
      UID: "frw5e3e256rk0hr7",
      PhotoUID: "prqjmzr1jlmr4mpb",
    };
    const video = new Video(values);
    assert.equal(video.hasId(), true);

    const values2 = {
      Title: "",
    };
    const video2 = new Video(values2);
    assert.equal(video2.hasId(), false);
  });

  it("should toggle like", () => {
    const values = {
      UID: "frw5e3e256rk0hr7",
      PhotoUID: "prqjmzr1jlmr4mpb",
      Title: "",
      TakenAtLocal: "",
      Description: "",
      Favorite: true,
      HDR: false,
      Mime: "",
      Type: "",
      Codec: "",
      Width: 0,
      Height: 0,
      Duration: 0,
      FPS: 0.0,
      Frames: 0,
      Projection: "",
      AspectRatio: 1.0,
      ColorProfile: "",
      Error: "",
    };
    const video = new Video(values);
    assert.equal(video.Favorite, true);
    video.toggleLike();
    assert.equal(video.Favorite, false);
    video.toggleLike();
    assert.equal(video.Favorite, true);
  });

  it("should return not placeholder", () => {
    const result = Video.notFound();
    assert.equal(result.UID, "");
    assert.equal(result.Favorite, false);
  });

  it("should test from file", () => {
    const values = {
      UID: "frwb9ojl70qn7nzx",
      PhotoUID: "prjwuh12nt0repcs",
      Name: "Videos/VID_20200609_163159.mp4",
      Root: "/",
      Hash: "81aefaee21a2882102a5cac0532f265965c7c679",
      Size: 22251038,
      Primary: false,
      Codec: "avc1",
      FileType: "mp4",
      MediaType: "video",
      Mime: "video/mp4",
      Video: true,
      Duration: 10540000000,
      FPS: 29.6094151191494,
      Frames: 312,
      Width: 1920,
      Height: 1080,
      Orientation: 1,
      AspectRatio: 1.78,
      Colors: "33B3E2299",
      Luminance: "A9AB7B976",
      Diff: 765,
      Chroma: 41,
      CreatedAt: "2022-10-17T18:39:01.362529069Z",
      UpdatedAt: "2023-06-17T09:10:39.84359394Z",
      Markers: [],
    };

    const file = new File(values);

    const values2 = {
      ID: "151-304",
      UID: "prjwuh12nt0repcs",
      Type: "video",
      TypeSrc: "",
      TakenAt: "2020-06-09T14:31:59Z",
      TakenAtLocal: "2020-06-09T16:31:59Z",
      TakenSrc: "meta",
      TimeZone: "Europe/Berlin",
      Path: "Videos",
      Name: "VID_20200609_163159",
      OriginalName: "",
      Title: "Nature / Meckenheim / 2020",
      Description: "A photo description.",
      Year: 2020,
      Month: 6,
      Day: 9,
      Country: "de",
      Stack: 0,
      Favorite: false,
      Private: false,
      Iso: 0,
      FocalLength: 0,
      FNumber: 0,
      Exposure: "",
      Quality: 4,
      Resolution: 2,
      Color: 3,
      Scan: false,
      Panorama: false,
      CameraID: 1,
      CameraModel: "Unknown",
      LensID: 1,
      LensModel: "Unknown",
      Lat: 49.4005,
      Lng: 8.2442,
      CellID: "s2:479636009cac",
      PlaceID: "de:bM4IIOpnFIDL",
      PlaceSrc: "meta",
      PlaceLabel: "Meckenheim, Rheinland-Pfalz, Germany",
      PlaceCity: "Meckenheim",
      PlaceState: "Rheinland-Pfalz",
      PlaceCountry: "de",
      InstanceID: "",
      FileUID: "frwb9ojf3uexhhy9",
      FileRoot: "sidecar",
      FileName: "Videos/VID_20200609_163159.mp4.jpg",
      Hash: "3fec1484f104601d3f80d1df3d1dfd1ddbf17de6",
      Width: 1920,
      Height: 1080,
      Portrait: false,
      Merged: true,
      CreatedAt: "2022-10-17T18:39:01.362529069Z",
      UpdatedAt: "2023-06-17T09:10:39.84359394Z",
      EditedAt: "0001-01-01T00:00:00Z",
      CheckedAt: "2023-06-17T04:40:10Z",
      DeletedAt: "0001-01-01T00:00:00Z",
      Files: [
        {
          UID: "frwb9ojf3uexhhy9",
          PhotoUID: "prjwuh12nt0repcs",
          Name: "Videos/VID_20200609_163159.mp4.jpg",
          Root: "sidecar",
          Hash: "3fec1484f104601d3f80d1df3d1dfd1ddbf17de6",
          Size: 81944,
          Primary: true,
          FileType: "jpg",
          MediaType: "image",
          Mime: "image/jpeg",
          Width: 1920,
          Height: 1080,
          Orientation: 1,
          AspectRatio: 1.78,
          Colors: "33B3E2299",
          Luminance: "A9AB7B976",
          Diff: 765,
          Chroma: 41,
          CreatedAt: "2022-10-17T18:39:01.362529069Z",
          UpdatedAt: "2023-06-17T09:10:39.84359394Z",
          Markers: [],
        },
        {
          UID: "frwb9ojl70qn7nzx",
          PhotoUID: "prjwuh12nt0repcs",
          Name: "Videos/VID_20200609_163159.mp4",
          Root: "/",
          Hash: "81aefaee21a2882102a5cac0532f265965c7c679",
          Size: 22251038,
          Primary: false,
          Codec: "avc1",
          FileType: "mp4",
          MediaType: "video",
          Mime: "video/mp4",
          Video: true,
          Duration: 10540000000,
          FPS: 29.6094151191494,
          Frames: 312,
          Width: 1920,
          Height: 1080,
          Orientation: 1,
          AspectRatio: 1.78,
          Colors: "33B3E2299",
          Luminance: "A9AB7B976",
          Diff: 765,
          Chroma: 41,
          CreatedAt: "2022-10-17T18:39:01.362529069Z",
          UpdatedAt: "2023-06-17T09:10:39.84359394Z",
          Markers: [],
        },
      ],
    };
    const photo = new Photo(values2);
    const result = Video.fromFile(photo, file);
    assert.equal(result.UID, "frwb9ojl70qn7nzx");
    assert.equal(result.PhotoUID, "prjwuh12nt0repcs");
    assert.equal(result.Description, "A photo description.");
    assert.equal(result.Width, 1920);
    assert.equal(result.Height, 1080);
    const playerSize = result.playerSize();
    assert.equal(playerSize.width, 705);
    assert.equal(playerSize.height, 397);
    const result2 = Video.fromFile();
    assert.isFalse(result2);
  });

  it("should test from files", () => {
    const values2 = {
      ID: "151-304",
      UID: "prjwuh12nt0repcs",
      Type: "video",
      TypeSrc: "",
      TakenAt: "2020-06-09T14:31:59Z",
      TakenAtLocal: "2020-06-09T16:31:59Z",
      TakenSrc: "meta",
      TimeZone: "Europe/Berlin",
      Path: "Videos",
      Name: "VID_20200609_163159",
      OriginalName: "",
      Title: "Nature / Meckenheim / 2020",
      Description: "My description.",
      Year: 2020,
      Month: 6,
      Day: 9,
      Country: "de",
      Stack: 0,
      Favorite: false,
      Private: false,
      Iso: 0,
      FocalLength: 0,
      FNumber: 0,
      Exposure: "",
      Quality: 4,
      Resolution: 2,
      Color: 3,
      Scan: false,
      Panorama: false,
      CameraID: 1,
      CameraModel: "Unknown",
      LensID: 1,
      LensModel: "Unknown",
      Lat: 49.4005,
      Lng: 8.2442,
      CellID: "s2:479636009cac",
      PlaceID: "de:bM4IIOpnFIDL",
      PlaceSrc: "meta",
      PlaceLabel: "Meckenheim, Rheinland-Pfalz, Germany",
      PlaceCity: "Meckenheim",
      PlaceState: "Rheinland-Pfalz",
      PlaceCountry: "de",
      InstanceID: "",
      FileUID: "frwb9ojf3uexhhy9",
      FileRoot: "sidecar",
      FileName: "Videos/VID_20200609_163159.mp4.jpg",
      Hash: "3fec1484f104601d3f80d1df3d1dfd1ddbf17de6",
      Width: 1920,
      Height: 1080,
      Portrait: false,
      Merged: true,
      CreatedAt: "2022-10-17T18:39:01.362529069Z",
      UpdatedAt: "2023-06-17T09:10:39.84359394Z",
      EditedAt: "0001-01-01T00:00:00Z",
      CheckedAt: "2023-06-17T04:40:10Z",
      DeletedAt: "0001-01-01T00:00:00Z",
      Files: [
        {
          UID: "frwb9ojf3uexhhy9",
          PhotoUID: "prjwuh12nt0repcs",
          Name: "Videos/VID_20200609_163159.mp4.jpg",
          Root: "sidecar",
          Hash: "3fec1484f104601d3f80d1df3d1dfd1ddbf17de6",
          Size: 81944,
          Primary: true,
          FileType: "jpg",
          MediaType: "image",
          Mime: "image/jpeg",
          Width: 1920,
          Height: 1080,
          Orientation: 1,
          AspectRatio: 1.78,
          Colors: "33B3E2299",
          Luminance: "A9AB7B976",
          Diff: 765,
          Chroma: 41,
          CreatedAt: "2022-10-17T18:39:01.362529069Z",
          UpdatedAt: "2023-06-17T09:10:39.84359394Z",
          Markers: [],
        },
        {
          UID: "frwb9ojl70qn7nzx",
          PhotoUID: "prjwuh12nt0repcs",
          Name: "Videos/VID_20200609_163159.mp4",
          Root: "/",
          Hash: "81aefaee21a2882102a5cac0532f265965c7c679",
          Size: 22251038,
          Primary: false,
          Codec: "avc1",
          FileType: "mp4",
          MediaType: "image",
          Mime: "video/mp4",
          Video: false,
          Duration: 10540000000,
          FPS: 29.6094151191494,
          Frames: 312,
          Width: 1920,
          Height: 1080,
          Orientation: 1,
          AspectRatio: 1.78,
          Colors: "33B3E2299",
          Luminance: "A9AB7B976",
          Diff: 765,
          Chroma: 41,
          CreatedAt: "2022-10-17T18:39:01.362529069Z",
          UpdatedAt: "2023-06-17T09:10:39.84359394Z",
          Markers: [],
        },
      ],
    };
    const photo = new Photo(values2);

    const values3 = {
      ID: "151-304",
      UID: "prjwuh12nt0repcs",
      Type: "video",
      TypeSrc: "",
      TakenAt: "2020-06-09T14:31:59Z",
      TakenAtLocal: "2020-06-09T16:31:59Z",
      TakenSrc: "meta",
      TimeZone: "Europe/Berlin",
      Path: "Videos",
      Name: "VID_20200609_163159",
      OriginalName: "",
      Title: "Nature / Meckenheim / 2020",
      Description: "My description.",
      Year: 2020,
      Month: 6,
      Day: 9,
      Country: "de",
      Stack: 0,
      Favorite: false,
      Private: false,
      Iso: 0,
      FocalLength: 0,
      FNumber: 0,
      Exposure: "",
      Quality: 4,
      Resolution: 2,
      Color: 3,
      Scan: false,
      Panorama: false,
      CameraID: 1,
      CameraModel: "Unknown",
      LensID: 1,
      LensModel: "Unknown",
      Lat: 49.4005,
      Lng: 8.2442,
      CellID: "s2:479636009cac",
      PlaceID: "de:bM4IIOpnFIDL",
      PlaceSrc: "meta",
      PlaceLabel: "Meckenheim, Rheinland-Pfalz, Germany",
      PlaceCity: "Meckenheim",
      PlaceState: "Rheinland-Pfalz",
      PlaceCountry: "de",
      InstanceID: "",
      FileUID: "frwb9ojf3uexhhy9",
      FileRoot: "sidecar",
      FileName: "Videos/VID_20200609_163159.mp4.jpg",
      Hash: "3fec1484f104601d3f80d1df3d1dfd1ddbf17de6",
      Width: 1920,
      Height: 1080,
      Portrait: false,
      Merged: true,
      CreatedAt: "2022-10-17T18:39:01.362529069Z",
      UpdatedAt: "2023-06-17T09:10:39.84359394Z",
      EditedAt: "0001-01-01T00:00:00Z",
      CheckedAt: "2023-06-17T04:40:10Z",
      DeletedAt: "0001-01-01T00:00:00Z",
      Files: [
        {
          UID: "frwb9ojf3uexhhy9",
          PhotoUID: "prjwuh12nt0repcs",
          Name: "Videos/VID_20200609_163159.mp4.jpg",
          Root: "sidecar",
          Hash: "3fec1484f104601d3f80d1df3d1dfd1ddbf17de6",
          Size: 81944,
          Primary: true,
          FileType: "jpg",
          MediaType: "image",
          Mime: "image/jpeg",
          Width: 1920,
          Height: 1080,
          Orientation: 1,
          AspectRatio: 1.78,
          Colors: "33B3E2299",
          Luminance: "A9AB7B976",
          Diff: 765,
          Chroma: 41,
          CreatedAt: "2022-10-17T18:39:01.362529069Z",
          UpdatedAt: "2023-06-17T09:10:39.84359394Z",
          Markers: [],
        },
        {
          UID: "frwb9ojl70qn7nzx",
          PhotoUID: "prjwuh12nt0repcs",
          Name: "Videos/VID_20200609_163159.mp4",
          Root: "/",
          Hash: "81aefaee21a2882102a5cac0532f265965c7c679",
          Size: 22251038,
          Primary: false,
          Codec: "avc1",
          FileType: "mp4",
          MediaType: "image",
          Mime: "video/mp4",
          Video: false,
          Duration: 10540000000,
          FPS: 29.6094151191494,
          Frames: 312,
          Width: 1920,
          Height: 1080,
          Orientation: 1,
          AspectRatio: 1.78,
          Colors: "33B3E2299",
          Luminance: "A9AB7B976",
          Diff: 765,
          Chroma: 41,
          CreatedAt: "2022-10-17T18:39:01.362529069Z",
          UpdatedAt: "2023-06-17T09:10:39.84359394Z",
          Markers: [],
        },
      ],
    };
    const photo2 = new Photo(values3);
    const Photos = [photo, photo2];
    const result = Video.fromFiles(Photos);
    assert.equal(result.length, 0);
    const values4 = {
      ID: "150-303",
      UID: "prjwuh026fdkp148",
      Type: "video",
      TypeSrc: "",
      TakenAt: "2020-06-09T14:42:50Z",
      TakenAtLocal: "2020-06-09T16:42:50Z",
      TakenSrc: "meta",
      TimeZone: "Europe/Berlin",
      Path: "Videos",
      Name: "20201216_141910_6E9CCAEC",
      OriginalName: "",
      Title: "Plant / Meckenheim / 2020",
      Description: "My description.",
      Year: 2020,
      Month: 6,
      Day: 9,
      Country: "de",
      Stack: 0,
      Favorite: false,
      Private: false,
      Iso: 0,
      FocalLength: 0,
      FNumber: 0,
      Exposure: "",
      Quality: 4,
      Resolution: 2,
      Color: 9,
      Scan: false,
      Panorama: false,
      CameraID: 1,
      CameraModel: "Unknown",
      LensID: 1,
      LensModel: "Unknown",
      Lat: 49.4006,
      Lng: 8.2519,
      CellID: "s2:479635f947fc",
      PlaceID: "de:bM4IIOpnFIDL",
      PlaceSrc: "meta",
      PlaceLabel: "Meckenheim, Rheinland-Pfalz, Germany",
      PlaceCity: "Meckenheim",
      PlaceState: "Rheinland-Pfalz",
      PlaceCountry: "de",
      InstanceID: "",
      FileUID: "frwb9oj2qg89d6ep",
      FileRoot: "sidecar",
      FileName: "Videos/20201216_141910_6E9CCAEC.mp4.jpg",
      Hash: "1e118d6181700d93a7d26c09122437f586a8b228",
      Width: 1920,
      Height: 1080,
      Portrait: false,
      Merged: true,
      CreatedAt: "2022-10-17T18:39:00.710296587Z",
      UpdatedAt: "2023-06-17T09:10:39.855222833Z",
      EditedAt: "0001-01-01T00:00:00Z",
      CheckedAt: "2023-06-17T04:40:10Z",
      DeletedAt: "0001-01-01T00:00:00Z",
      Files: [
        {
          UID: "frwb9oj2qg89d6ep",
          PhotoUID: "prjwuh026fdkp148",
          Name: "Videos/20201216_141910_6E9CCAEC.mp4.jpg",
          Root: "sidecar",
          Hash: "1e118d6181700d93a7d26c09122437f586a8b228",
          Size: 109771,
          Primary: true,
          FileType: "jpg",
          MediaType: "image",
          Mime: "image/jpeg",
          Width: 1920,
          Height: 1080,
          Orientation: 1,
          AspectRatio: 1.78,
          Colors: "+Inf",
          Luminance: "76CA25596",
          Diff: 755,
          Chroma: 33,
          CreatedAt: "2022-10-17T18:39:00.710296587Z",
          UpdatedAt: "2023-06-17T09:10:39.855222833Z",
          Markers: [],
        },
        {
          UID: "frwb9oj2uddhfqte",
          PhotoUID: "prjwuh026fdkp148",
          Name: "Videos/20201216_141910_6E9CCAEC.mp4",
          Root: "/",
          Hash: "48eeda078916bfc4b75116d14f2b193b3c389fd9",
          Size: 7112164,
          Primary: false,
          Codec: "avc1",
          FileType: "mp4",
          MediaType: "video",
          Mime: "video/mp4",
          Video: true,
          Duration: 3200000000,
          FPS: 28.8113241030388,
          Frames: 92,
          Width: 1920,
          Height: 1080,
          Orientation: 1,
          AspectRatio: 1.78,
          Colors: "+Inf",
          Luminance: "76CA25596",
          Diff: 755,
          Chroma: 33,
          CreatedAt: "2022-10-17T18:39:00.710296587Z",
          UpdatedAt: "2023-06-17T09:10:39.855222833Z",
          Markers: [],
        },
      ],
    };
    const photo3 = new Photo(values4);
    const Photos2 = [photo, photo2, photo3];
    const result2 = Video.fromFiles(Photos2);
    assert.equal(result2.length, 1);
    assert.equal(result2[0].UID, "frwb9oj2uddhfqte");
    assert.equal(result2[0].Description, "My description.");
    assert.equal(result2[0].Width, 1920);
    assert.equal(result2[0].Height, 1080);
    const playerSize = result2[0].playerSize();
    assert.equal(playerSize.width, 705);
    assert.equal(playerSize.height, 397);
    const values5 = {
      ID: "153-313",
      UID: "prjwuh13ku8mztgh",
      Type: "live",
      TypeSrc: "",
      TakenAt: "2020-07-11T15:40:24Z",
      TakenAtLocal: "2020-07-11T17:40:24Z",
      TakenSrc: "meta",
      TimeZone: "Europe/Berlin",
      Path: "Videos",
      Name: "VID_20200711_174025",
      OriginalName: "",
      Title: "Flower / Berlin / 2020",
      Description: "A flower.",
      Year: 2020,
      Month: 7,
      Day: 11,
      Country: "de",
      Stack: 0,
      Favorite: true,
      Private: false,
      Iso: 0,
      FocalLength: 0,
      FNumber: 0,
      Exposure: "",
      Quality: 7,
      Resolution: 2,
      Color: 6,
      Scan: false,
      Panorama: false,
      CameraID: 1,
      CameraModel: "Unknown",
      LensID: 1,
      LensModel: "Unknown",
      Lat: 52.4553,
      Lng: 13.3002,
      CellID: "s2:47a85a650554",
      PlaceID: "de:4K7GUHGWzeqE",
      PlaceSrc: "meta",
      PlaceLabel: "Dahlem, Berlin, Germany",
      PlaceCity: "Berlin",
      PlaceState: "Berlin",
      PlaceCountry: "de",
      InstanceID: "",
      FileUID: "frwb9oj20m97fv6x",
      FileRoot: "sidecar",
      FileName: "Videos/VID_20200711_174025.mp4.jpg",
      Hash: "2e281e2bdfe22a9a0ebbbe81a7370b2da88b6cc9",
      Width: 1080,
      Height: 1920,
      Portrait: true,
      Merged: true,
      CreatedAt: "2022-10-17T18:39:01.431115253Z",
      UpdatedAt: "2023-06-17T09:10:39.991145708Z",
      EditedAt: "0001-01-01T00:00:00Z",
      CheckedAt: "2023-06-17T04:40:10Z",
      DeletedAt: "0001-01-01T00:00:00Z",
      Files: [
        {
          UID: "frwb9oj20m97fv6x",
          PhotoUID: "prjwuh13ku8mztgh",
          Name: "Videos/VID_20200711_174025.mp4.jpg",
          Root: "sidecar",
          Hash: "2e281e2bdfe22a9a0ebbbe81a7370b2da88b6cc9",
          Size: 113509,
          Primary: true,
          FileType: "jpg",
          MediaType: "image",
          Mime: "image/jpeg",
          Portrait: true,
          Width: 1080,
          Height: 1920,
          Orientation: 1,
          AspectRatio: 0.56,
          Colors: "666239222",
          Luminance: "999A688B9",
          Diff: 767,
          Chroma: 29,
          CreatedAt: "2022-10-17T18:39:01.431115253Z",
          UpdatedAt: "2023-06-17T09:10:39.991145708Z",
          Markers: [],
        },
      ],
    };
    const photo4 = new Photo(values5);
    const Photos3 = [photo3, photo4];
    const result3 = Video.fromFiles(Photos3);
    assert.equal(result3.length, 1);
    assert.equal(result3[0].UID, "frwb9oj2uddhfqte");
    assert.equal(result3[0].Description, "My description.");
    assert.equal(result3[0].Width, 1920);
    assert.equal(result3[0].Height, 1080);
  });

  it("should test from files", () => {
    const Photos = [];
    const result = Video.fromFiles(Photos);
    assert.equal(result, "");
  });

  it("should test from photo", () => {
    const values = {
      ID: "153-313",
      UID: "prjwuh13ku8mztgh",
      Type: "live",
      TypeSrc: "",
      TakenAt: "2020-07-11T15:40:24Z",
      TakenAtLocal: "2020-07-11T17:40:24Z",
      TakenSrc: "meta",
      TimeZone: "Europe/Berlin",
      Path: "Videos",
      Name: "VID_20200711_174025",
      OriginalName: "",
      Title: "Flower / Berlin / 2020",
      Description: "Video description.",
      Year: 2020,
      Month: 7,
      Day: 11,
      Country: "de",
      Stack: 0,
      Favorite: true,
      Private: false,
      Iso: 0,
      FocalLength: 0,
      FNumber: 0,
      Exposure: "",
      Quality: 7,
      Resolution: 2,
      Color: 6,
      Scan: false,
      Panorama: false,
      CameraID: 1,
      CameraModel: "Unknown",
      LensID: 1,
      LensModel: "Unknown",
      Lat: 52.4553,
      Lng: 13.3002,
      CellID: "s2:47a85a650554",
      PlaceID: "de:4K7GUHGWzeqE",
      PlaceSrc: "meta",
      PlaceLabel: "Dahlem, Berlin, Germany",
      PlaceCity: "Berlin",
      PlaceState: "Berlin",
      PlaceCountry: "de",
      InstanceID: "",
      FileUID: "frwb9oj20m97fv6x",
      FileRoot: "sidecar",
      FileName: "Videos/VID_20200711_174025.mp4.jpg",
      Hash: "2e281e2bdfe22a9a0ebbbe81a7370b2da88b6cc9",
      Width: 1080,
      Height: 1920,
      Portrait: true,
      Merged: true,
      CreatedAt: "2022-10-17T18:39:01.431115253Z",
      UpdatedAt: "2023-06-17T09:10:39.991145708Z",
      EditedAt: "0001-01-01T00:00:00Z",
      CheckedAt: "2023-06-17T04:40:10Z",
      DeletedAt: "0001-01-01T00:00:00Z",
      Files: [
        {
          UID: "frwb9oj3ohs3og1h",
          PhotoUID: "prjwuh13ku8mztgh",
          Name: "Videos/VID_20200711_174025.mp4",
          Root: "/",
          Hash: "12bb59db8ca11b6a30c1bba40c9e8ffff5437087",
          Size: 5052870,
          Primary: false,
          Codec: "avc1",
          FileType: "mp4",
          MediaType: "video",
          Mime: "video/mp4",
          Portrait: true,
          Video: true,
          Duration: 2620000000,
          FPS: 27.8899176037594,
          Frames: 73,
          Width: 1080,
          Height: 1920,
          Orientation: 1,
          AspectRatio: 0.56,
          Colors: "666239222",
          Luminance: "999A688B9",
          Diff: 767,
          Chroma: 29,
          CreatedAt: "2022-10-17T18:39:01.431115253Z",
          UpdatedAt: "2023-06-17T09:10:39.991145708Z",
          Markers: [],
        },
      ],
    };
    const photo = new Photo(values);
    const result = Video.fromPhoto(photo);
    assert.equal(result.UID, "frwb9oj3ohs3og1h");
    assert.equal(result.Description, "Video description.");
    assert.equal(result.Width, 1080);
    assert.equal(result.Height, 1920);
    const values3 = {
      ID: 8,
      UID: "ABC124",
      Description: "FooBar",
    };
    const photo3 = new Photo(values3);
    const result2 = Video.fromPhoto(photo3);
    assert.equal(result2.UID, "");
    const values2 = {
      ID: "153-313",
      UID: "prjwuh13ku8mztgh",
      Type: "live",
      TypeSrc: "",
      TakenAt: "2020-07-11T15:40:24Z",
      TakenAtLocal: "2020-07-11T17:40:24Z",
      TakenSrc: "meta",
      TimeZone: "Europe/Berlin",
      Path: "Videos",
      Name: "VID_20200711_174025",
      OriginalName: "",
      Title: "Flower / Berlin / 2020",
      Description: "My description.",
      Year: 2020,
      Month: 7,
      Day: 11,
      Country: "de",
      Stack: 0,
      Favorite: true,
      Private: false,
      Iso: 0,
      FocalLength: 0,
      FNumber: 0,
      Exposure: "",
      Quality: 7,
      Resolution: 2,
      Color: 6,
      Scan: false,
      Panorama: false,
      CameraID: 1,
      CameraModel: "Unknown",
      LensID: 1,
      LensModel: "Unknown",
      Lat: 52.4553,
      Lng: 13.3002,
      CellID: "s2:47a85a650554",
      PlaceID: "de:4K7GUHGWzeqE",
      PlaceSrc: "meta",
      PlaceLabel: "Dahlem, Berlin, Germany",
      PlaceCity: "Berlin",
      PlaceState: "Berlin",
      PlaceCountry: "de",
      InstanceID: "",
      FileUID: "frwb9oj20m97fv6x",
      FileRoot: "sidecar",
      FileName: "Videos/VID_20200711_174025.mp4.jpg",
      Hash: "2e281e2bdfe22a9a0ebbbe81a7370b2da88b6cc9",
      Width: 1080,
      Height: 1920,
      Portrait: true,
      Merged: true,
      CreatedAt: "2022-10-17T18:39:01.431115253Z",
      UpdatedAt: "2023-06-17T09:10:39.991145708Z",
      EditedAt: "0001-01-01T00:00:00Z",
      CheckedAt: "2023-06-17T04:40:10Z",
      DeletedAt: "0001-01-01T00:00:00Z",
      Files: [
        {
          UID: "frwb9oj3ohs3og1h",
          PhotoUID: "prjwuh13ku8mztgh",
          Name: "Videos/VID_20200711_174025.mp4",
          Root: "/",
          Hash: "12bb59db8ca11b6a30c1bba40c9e8ffff5437087",
          Size: 5052870,
          Primary: false,
          Codec: "avc1",
          FileType: "mp4",
          MediaType: "video",
          Mime: "video/mp4",
          Portrait: true,
          Video: true,
          Duration: 2620000000,
          FPS: 27.8899176037594,
          Frames: 73,
          Width: 1080,
          Height: 1920,
          Orientation: 1,
          AspectRatio: 0.56,
          Colors: "666239222",
          Luminance: "999A688B9",
          Diff: 767,
          Chroma: 29,
          CreatedAt: "2022-10-17T18:39:01.431115253Z",
          UpdatedAt: "2023-06-17T09:10:39.991145708Z",
          Markers: [],
        },
      ],
    };
    const photo2 = new Photo(values2);
    const result3 = Video.fromPhoto(photo2);
    assert.equal(result3.UID, "frwb9oj3ohs3og1h");
    assert.equal(result3.Title, "Flower / Berlin / 2020");
    assert.equal(result3.Description, "My description.");
  });

  it("should test from photos", () => {
    const values = {
      ID: "153-313",
      UID: "prjwuh13ku8mztgh",
      Type: "live",
      TypeSrc: "",
      TakenAt: "2020-07-11T15:40:24Z",
      TakenAtLocal: "2020-07-11T17:40:24Z",
      TakenSrc: "meta",
      TimeZone: "Europe/Berlin",
      Path: "Videos",
      Name: "VID_20200711_174025",
      OriginalName: "",
      Title: "Flower / Berlin / 2020",
      Description: "Other description.",
      Year: 2020,
      Month: 7,
      Day: 11,
      Country: "de",
      Stack: 0,
      Favorite: true,
      Private: false,
      Iso: 0,
      FocalLength: 0,
      FNumber: 0,
      Exposure: "",
      Quality: 7,
      Resolution: 2,
      Color: 6,
      Scan: false,
      Panorama: false,
      CameraID: 1,
      CameraModel: "Unknown",
      LensID: 1,
      LensModel: "Unknown",
      Lat: 52.4553,
      Lng: 13.3002,
      CellID: "s2:47a85a650554",
      PlaceID: "de:4K7GUHGWzeqE",
      PlaceSrc: "meta",
      PlaceLabel: "Dahlem, Berlin, Germany",
      PlaceCity: "Berlin",
      PlaceState: "Berlin",
      PlaceCountry: "de",
      InstanceID: "",
      FileUID: "frwb9oj20m97fv6x",
      FileRoot: "sidecar",
      FileName: "Videos/VID_20200711_174025.mp4.jpg",
      Hash: "2e281e2bdfe22a9a0ebbbe81a7370b2da88b6cc9",
      Width: 1080,
      Height: 1920,
      Portrait: true,
      Merged: true,
      CreatedAt: "2022-10-17T18:39:01.431115253Z",
      UpdatedAt: "2023-06-17T09:10:39.991145708Z",
      EditedAt: "0001-01-01T00:00:00Z",
      CheckedAt: "2023-06-17T04:40:10Z",
      DeletedAt: "0001-01-01T00:00:00Z",
      Files: [
        {
          UID: "frwb9oj3ohs3og1h",
          PhotoUID: "prjwuh13ku8mztgh",
          Name: "Videos/VID_20200711_174025.mp4",
          Root: "/",
          Hash: "12bb59db8ca11b6a30c1bba40c9e8ffff5437087",
          Size: 5052870,
          Primary: false,
          Codec: "avc1",
          FileType: "mp4",
          MediaType: "video",
          Mime: "video/mp4",
          Portrait: true,
          Video: true,
          Duration: 2620000000,
          FPS: 27.8899176037594,
          Frames: 73,
          Width: 1080,
          Height: 1920,
          Orientation: 1,
          AspectRatio: 0.56,
          Colors: "666239222",
          Luminance: "999A688B9",
          Diff: 767,
          Chroma: 29,
          CreatedAt: "2022-10-17T18:39:01.431115253Z",
          UpdatedAt: "2023-06-17T09:10:39.991145708Z",
          Markers: [],
        },
      ],
    };
    const photo = new Photo(values);
    const Photos = [photo];
    const result = Video.fromPhotos(Photos);
    const m = result.videos[0];
    assert.equal(m.UID, "frwb9oj3ohs3og1h");
    assert.equal(m.Description, "Other description.");
    assert.equal(m.Width, 1080);
    assert.equal(m.Height, 1920);
    assert.equal(m.loop(), true);
    assert.equal(m.url(), "/api/v1/videos/12bb59db8ca11b6a30c1bba40c9e8ffff5437087/public/avc");
    assert.equal(m.downloadUrl(), "/api/v1/dl/12bb59db8ca11b6a30c1bba40c9e8ffff5437087?t=2lbh9x09");
    assert.equal(m.posterUrl(), "/api/v1/t/12bb59db8ca11b6a30c1bba40c9e8ffff5437087/public/fit_720");
  });
});
